==> aws-sdk-cpp-1.11.476-1-x86_64.pkg.tar.zst: usr/include/aws/quicksight/model/WaterfallChartOptions.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/quicksight/QuickSight_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace QuickSight
{
namespace Model
{

  /**
   * <p>The options that determine the presentation of a waterfall
   * visual.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/quicksight-2018-04-01/WaterfallChartOptions">AWS
   * API Reference</a></p>
   */
  class WaterfallChartOptions
  {
  public:
    AWS_QUICKSIGHT_API WaterfallChartOptions();
    AWS_QUICKSIGHT_API WaterfallChartOptions(Aws::Utils::Json::JsonView jsonValue);
    AWS_QUICKSIGHT_API WaterfallChartOptions& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_QUICKSIGHT_API Aws::Utils::Json::JsonValue Jsonize() const;


    ///@{
    /**
     * <p>This option determines the total bar label of a waterfall visual.</p>
     */
    inline const Aws::String& GetTotalBarLabel() const{ return m_totalBarLabel; }
    inline bool TotalBarLabelHasBeenSet() const { return m_totalBarLabelHasBeenSet; }
    inline void SetTotalBarLabel(const Aws::String& value) { m_totalBarLabelHasBeenSet = true; m_totalBarLabel = value; }
    inline void SetTotalBarLabel(Aws::String&& value) { m_totalBarLabelHasBeenSet = true; m_totalBarLabel = std::move(value); }
    inline void SetTotalBarLabel(const char* value) { m_totalBarLabelHasBeenSet = true; m_totalBarLabel.assign(value); }
    inline WaterfallChartOptions& WithTotalBarLabel(const Aws::String& value) { SetTotalBarLabel(value); return *this;}
    inline WaterfallChartOptions& WithTotalBarLabel(Aws::String&& value) { SetTotalBarLabel(std::move(value)); return *this;}
    inline WaterfallChartOptions& WithTotalBarLabel(const char* value) { SetTotalBarLabel(value); return *this;}
    ///@}
  private:

    Aws::String m_totalBarLabel;
    bool m_totalBarLabelHasBeenSet = false;
  };

} // namespace Model
} // namespace QuickSight
} // namespace Aws

==> aws-sdk-cpp-1.11.667-1-x86_64.pkg.tar.zst: usr/include/aws/quicksight/model/WaterfallChartOptions.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/quicksight/QuickSight_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace QuickSight
{
namespace Model
{

  /**
   * <p>The options that determine the presentation of a waterfall
   * visual.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/quicksight-2018-04-01/WaterfallChartOptions">AWS
   * API Reference</a></p>
   */
  class WaterfallChartOptions
  {
  public:
    AWS_QUICKSIGHT_API WaterfallChartOptions() = default;
    AWS_QUICKSIGHT_API WaterfallChartOptions(Aws::Utils::Json::JsonView jsonValue);
    AWS_QUICKSIGHT_API WaterfallChartOptions& operator=(Aws::Utils::Json::JsonView jsonValue);
    AWS_QUICKSIGHT_API Aws::Utils::Json::JsonValue Jsonize() const;


    ///@{
    /**
     * <p>This option determines the total bar label of a waterfall visual.</p>
     */
    inline const Aws::String& GetTotalBarLabel() const { return m_totalBarLabel; }
    inline bool TotalBarLabelHasBeenSet() const { return m_totalBarLabelHasBeenSet; }
    template<typename TotalBarLabelT = Aws::String>
    void SetTotalBarLabel(TotalBarLabelT&& value) { m_totalBarLabelHasBeenSet = true; m_totalBarLabel = std::forward<TotalBarLabelT>(value); }
    template<typename TotalBarLabelT = Aws::String>
    WaterfallChartOptions& WithTotalBarLabel(TotalBarLabelT&& value) { SetTotalBarLabel(std::forward<TotalBarLabelT>(value)); return *this;}
    ///@}
  private:

    Aws::String m_totalBarLabel;
    bool m_totalBarLabelHasBeenSet = false;
  };

} // namespace Model
} // namespace QuickSight
} // namespace Aws
